PushNotSupportedException class

Exception thrown when push notifications are not supported on the platform

Inheritance

Constructors

PushNotSupportedException()

Properties

code String?
Optional error code
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
Error message
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited